Function rshooks_api::api::slot_count
source · pub fn slot_count(slot_no: u32) -> Result<i64>Expand description
Count the elements of an array object in a slot
pub fn slot_count(slot_no: u32) -> Result<i64>Count the elements of an array object in a slot