Macro rshooks_api::uninit_buf

source ·
macro_rules! uninit_buf {
    () => { ... };
}
Assumes uninitialized as initialized

Rust doesn’t allow to use uninitialized values, but we need them to avoid memset, memcpy extra functions call in wasm binary. Use this macro every time you need a buffer.

Example

let mut buf: [u8; 20] = uninit_buf!();