Function rshooks_api::api::state_foreign
source · pub fn state_foreign(
data: &mut [u8],
key: &StateKey,
namespace: &NameSpace,
accid: &AccountId,
) -> Result<i64>Expand description
Retrieve the data pointed to, on another account, by a Hook State key and write it to an output buffer